
def get_boards(projectid):
    """
    Get available projects
    @param projectid: Project id
    @type projectid: <id>
    @return: List of boards
    """
    from ppapiaccess import connect
    
    if not projectid:
        raise ValueError('Parameter projectid must be supplied')
    
    conn = connect()
    response = conn.request('GET','/1/project/%d/boards.json'%int(projectid))
    if response.status_code != 200:
        raise RuntimeError('Error occured. Server returned http status code %d. Return message: %s'%(response.status_code, response.text))

    data = response.json()
    return data


def create_board(projectid, name):
    """
    Create a new board
    @param projectid: Id of project to create board in
    @type projectid: <id>
    @param name: Name of board to be created
    @type name: '<name>'
    @return: Board data
    """
    from ppapiaccess import connect
    
    if not projectid:
        raise ValueError('Parameter projectid must be supplied')
    
    conn = connect()
    response = conn.request('POST','/1/project/%d/boards/create-new.json'%int(projectid),{'name':name})
    if response.status_code != 200:
        raise RuntimeError('Error occured. Server returned http status code %d. Return message: %s'%(response.status_code, response.text))

    data = response.json()
    return data



def get_cards(boardid):
    """
    Get available cards on a specific board
    @param boardid: Id of the board
    @type boardid: <id>
    @returns cards
    @note The terminology is confusing. The public terminology is "Card" but in API it's "Activity".
    """
    from ppapiaccess import connect
    
    if not boardid:
        raise ValueError('Parameter boardid must be supplied')
    
    conn = connect()
    response = conn.request('GET','/1/board/%d/activities.json'%int(boardid))
    if response.status_code != 200:
        raise RuntimeError('Error occured. Server returned http status code %d. Return message: %s'%(response.status_code, response.text))

    data = response.json()
    return data



def create_card(projectid, boardid, name):
    """
    Create a new Card
    @param projectid: Id of project to card in
    @type projectid: <id>
    @param boardid: Id of board to create card in
    @type boardid: <id>
    @param name: Name of card to be created
    @type name: '<name>'
    @return: card data
    """
    from ppapiaccess import connect
    
    if not (projectid and boardid and name):
        raise ValueError('Parameters projectid, boardid and name must be supplied')
    
    conn = connect()
    response = conn.request('POST','/1/project/%d/activities/create-new.json'%int(projectid),{'title':name, 'board_id':boardid})
    if response.status_code != 200:
        raise RuntimeError('Error occured. Server returned http status code %d. Return message: %s'%(response.status_code, response.text))

    data = response.json()
    return data


def set_card_status(cardid, statusid):
    """
    Create a new Card
    
    @param cardid: Id of card to update
    @type cardid: <id>
    @param statusid: Id of status to be set
    @type statusid: <id>
    """
    from ppapiaccess import connect
    
    if not (cardid and statusid):
        raise ValueError('Parameters cardid and statusid must be supplied')
    
    conn = connect()
    response = conn.request('POST','/1/activity/%d/properties.json'%int(cardid),{'progress_id':statusid})
    if response.status_code != 200:
        raise RuntimeError('Error occured. Server returned http status code %d. Return message: %s'%(response.status_code, response.text))

    data = response.json()
    return data
